@@ -23,12 +23,26 @@ class RedisHelper:
         await self.get_connection().set(name, value, ex, px, nx, xx, keepttl)
 
     async def get(self, name):
-        await self.get_connection().get(name)
+        return await self.get_connection().get(name)
 
-    async def delete(self, name):
-        await self.get_connection().delete(name)
+    async def delete(self, names):
+        if isinstance(names, list) or isinstance(names, tuple):
+            await self.get_connection().delete(*names)
+        else:
+            await self.get_connection().delete(names)
 
     async def rpush(self, name, values: list, time=None):
         await self.get_connection().rpush(name, *values)
         if time:
             await self.get_connection().expire(name, time)
+
+    async def hset(self, name, key=None, value=None, mapping_dict=None, time=None):
+        await self.get_connection().hset(name, key=key, value=value, mapping=mapping_dict)
+        if time:
+            await self.get_connection().expire(name, time)
+
+    async def hgetall(self, name):
+        return await self.get_connection().hgetall(name)
+
+    async def hget(self, name, key):
+        return await self.get_connection().hget(name, key)
